@@ -3,7 +3,6 @@ from enum import Enum
 import yaml
 
 
-
 class RunMode(Enum):
     LOCAL = "local"
     KUBERNETES = "kubernetes"
@@ -31,7 +30,7 @@ class ApiClient:
     def load_env(self):
         self.hyperdata_addr = os.environ["hyperdataAddr"]
         self.experiment_id = os.environ["experimentId"]
-        self.train_id = os.environ["trainId"] if "trainId" in os.environ else None
+        self.train_id = os.environ["trainId"]
         self.inference_id = os.environ["inferenceId"] if "inferenceId" in os.environ else None
         self.serving_id = os.environ["servingId"] if "servingId" in os.environ else None
         self.pvc_mount_path = os.environ["pvcMountPath"]
