@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from dataclasses_json import dataclass_json, LetterCase
 from typing import List, Dict
 
 # example
@@ -18,7 +17,6 @@ from typing import List, Dict
 # ]
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass
 class DataObject:
     id: str
