@@ -24,6 +24,7 @@ class PredefinedAIApi:
             )
         self.experiment_id = self.api_client.experiment_id
         self.train_id = self.api_client.train_id
+        self.inference_id = self.api_client.inference_id
 
     def get_models(self) -> Optional[List[ModelPredefinedaiDto]]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
@@ -69,7 +70,7 @@ class PredefinedAIApi:
             print("Current mode is local, Skip insert_visualizations.")
 
     def upload_inference_csv(self, inference_csv_path: str):
-        if self.api_client == RunMode.KUBERNETES:
+        if self.api_client.run_mode == RunMode.KUBERNETES:
             self.predefinedai_client.upload_inference_csv(
                 experiment_id=self.experiment_id,
                 inference_id=self.inference_id,
