@@ -5,7 +5,7 @@ from mlplatform_lib.mlplatform.mlplatform_http_client import (
 )
 from mlplatform_lib.dataclass.model.model_predefinedai_dto import ModelPredefinedaiDto
 from typing import List
-from mlplatform_lib.utils.dataclass_utils import from_dict
+from mlplatform_lib.utils.dataclass_utils import to_dict, from_dict
 
 
 class PredefinedAIHttpClient(MlPlatformHttpClient):
@@ -35,7 +35,7 @@ class PredefinedAIHttpClient(MlPlatformHttpClient):
             "models",
             {"experiments": experiment_id, "trains": train_id},
             {},
-            model.to_dict(),
+            to_dict(model),
             auth,
             MlPlatformRequestType.CREATE,
         )
